==> haskell-ipython-kernel-0.11.0.0-129-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ipython-kernel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ipython-kernel
version:              0.11.0.0
visibility:           public
id:                   ipython-kernel-0.11.0.0-95HSn4xIYkfK9Yd7GxgYXs
key:                  ipython-kernel-0.11.0.0-95HSn4xIYkfK9Yd7GxgYXs
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A library for creating kernels for IPython frontends
description:
    ipython-kernel is a library for communicating with frontends for the interactive IPython framework. It is used extensively in IHaskell, the interactive Haskell environment.

category:             Development
abi:                  faae98268d6be2127dbdeb7197614bae
exposed:              True
exposed-modules:
    IHaskell.IPython.EasyKernel IHaskell.IPython.Kernel
    IHaskell.IPython.Message.Parser IHaskell.IPython.Message.UUID
    IHaskell.IPython.Types IHaskell.IPython.ZeroMQ

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipython-kernel
hs-libraries:         HSipython-kernel-0.11.0.0-95HSn4xIYkfK9Yd7GxgYXs
depends:
    aeson-2.1.2.1-FurzwiqHIOZ8NUBnR3RWtD base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-CjCjILhZEuQLAyDxkDCVop directory-1.3.7.1
    filepath-1.4.2.2 memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    parsec-3.1.16.1 process-1.6.18.0
    temporary-1.3-EG3p5EUtjekFmwlm9f2IPf text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-3ZBRQjn1NdW5zFXXpEAC63
    uuid-1.3.16-8czFtbZqpi3AyOuvGDHcxt
    zeromq4-haskell-0.8.0-KrdAoHhkHEDJDSXWiW8Sfy

haddock-interfaces:
    /usr/share/doc/haskell-ipython-kernel/html/ipython-kernel.haddock

haddock-html:         /usr/share/doc/haskell-ipython-kernel/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ipython-kernel-0.11.0.0-130-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ipython-kernel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ipython-kernel
version:              0.11.0.0
visibility:           public
id:                   ipython-kernel-0.11.0.0-17DaYDyiSoaAeW01x9sqoe
key:                  ipython-kernel-0.11.0.0-17DaYDyiSoaAeW01x9sqoe
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A library for creating kernels for IPython frontends
description:
    ipython-kernel is a library for communicating with frontends for the interactive IPython framework. It is used extensively in IHaskell, the interactive Haskell environment.

category:             Development
abi:                  68e8dd58020076f85db66ee777c18c3a
exposed:              True
exposed-modules:
    IHaskell.IPython.EasyKernel IHaskell.IPython.Kernel
    IHaskell.IPython.Message.Parser IHaskell.IPython.Message.UUID
    IHaskell.IPython.Types IHaskell.IPython.ZeroMQ

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipython-kernel
hs-libraries:         HSipython-kernel-0.11.0.0-17DaYDyiSoaAeW01x9sqoe
depends:
    aeson-2.1.2.1-8PRfz0Kg6mwK2TOn7o5BkY base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-6KdnxY3pikWKXg5F5ljjPW directory-1.3.7.1
    filepath-1.4.2.2 memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    parsec-3.1.16.1 process-1.6.18.0
    temporary-1.3-6YbEjLKDNjc6IO1VlPHH38 text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-8Q4WKXtMGLf6eJrIPiNhPJ
    uuid-1.3.16-95bIAEFK6KQ74QGAgxfLvk
    zeromq4-haskell-0.8.0-KeyB8r3iAS34KmpkuJsKnR

haddock-interfaces:
    /usr/share/doc/haskell-ipython-kernel/html/ipython-kernel.haddock

haddock-html:         /usr/share/doc/haskell-ipython-kernel/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
